@@ -206,7 +206,7 @@ from ae.gui_app import (
     FLOW_KEY_SEP, flow_action, flow_class_name, flow_path_id, id_of_flow, update_tap_kwargs, MainAppBase)
 
 
-__version__ = '0.1.35'
+__version__ = '0.2.35'
 
 
 register_package_translations()
@@ -864,7 +864,8 @@ class HelpAppBase(MainAppBase, ABC):
     def call_method_delayed(self, delay: float, callback: Union[Callable, str], *args, **kwargs) -> Any:
         """ delayed call of passed callable/method with args/kwargs catching and logging exceptions preventing app exit.
 
-        :param delay:           delay in seconds when to call the callable/method specified by :paramref:`.callback`.
+        :param delay:           delay in seconds before calling the callable/method specified by
+                                :paramref:`~call_method_delayed.callback`.
         :param callback:        either callable or name of the main app method to call.
         :param args:            args passed to the callable/main-app-method to be called.
         :param kwargs:          kwargs passed to the callable/main-app-method to be called.
@@ -924,7 +925,7 @@ class HelpAppBase(MainAppBase, ABC):
 
         :param help_vars:       locals (args/kwargs) of overwritten :meth:`~ae.gui_app.MainAppBase.change_flow` method.
 
-                                items passed to the help text renderer:
+                                items passed to the help text formater:
                                     * `count`: optional number used to render a pluralized help text
                                       for this app state change.
 
@@ -954,7 +955,7 @@ class HelpAppBase(MainAppBase, ABC):
 
         :param help_id:         help id to show help text for.
         :param help_vars:       variables used in the conversion of the f-string expression to a string.
-                                optional items passed to the help text renderer:
+                                optional items passed to the help text formater:
                                 * `count`: optional number used to render a pluralized help text.
                                 * `self`: target widget to show help text for.
         :param key_suffix:      suffix to the key used if the translation is a dict.
